.. index::
   single: Class reference; ConfigurationManager
   single: Monte Carlo; Configuration manager

Configuration manager
=====================

.. autoclass:: mchammer.ConfigurationManager
   :members:
   :undoc-members:
   :inherited-members:
